@@ -92,23 +92,12 @@ pub(crate) fn generate_type_modules(type_registrar: &TypeRegistrar) -> String {
                 .map(generate_custom_type)
                 .collect::<Vec<String>>()
                 .join("\n\n");
-            format!(
-                "
-        pub mod {mod_name} {{
-            use postgres_types::{{FromSql, ToSql}};
-
-            {tys_str} 
-        }}"
-            )
+            format!("pub mod {mod_name} {{ use postgres_types::{{FromSql, ToSql}}; {tys_str} }}")
         })
         .collect::<Vec<String>>()
         .join("\n\n");
 
-    format!(
-        "pub mod types {{
-    {schema_modules}        
-}}"
-    )
+    format!("pub mod types {{ {schema_modules} }}")
 }
 
 pub(crate) fn generate_query_struct(query: &PreparedQuery) -> Result<Option<String>, Error> {
@@ -120,14 +109,13 @@ pub(crate) fn generate_query_struct(query: &PreparedQuery) -> Result<Option<Stri
             } else {
                 param_ty.rust_ty_usage_path.clone()
             };
-            field_strings.push(format!(r#"pub {} : {}"#, param.name, ty_string));
+            field_strings.push(format!("pub {} : {}", param.name, ty_string));
         }
         let fields_string = field_strings.join(",");
         let struct_name = query.name.to_upper_camel_case();
 
         Ok(Some(format!(
-            r#"#[derive(Debug, Clone, PartialEq)]
-pub struct {struct_name} {{{fields_string}}}"#
+            "#[derive(Debug, Clone, PartialEq)] pub struct {struct_name} {{{fields_string}}}"
         )))
     } else {
         Ok(None)
@@ -288,10 +276,7 @@ pub(crate) fn generate(
     modules: Vec<PreparedModule>,
     destination: &str,
 ) -> Result<(), Error> {
-    let query_imports = r#"
-use cornucopia_client::GenericClient;
-use tokio_postgres::Error;"#;
-
+    let query_imports = "use cornucopia_client::GenericClient;\nuse tokio_postgres::Error;";
     let type_modules = generate_type_modules(type_registrar);
 
     let mut query_modules = Vec::new();
@@ -305,20 +290,17 @@ use tokio_postgres::Error;"#;
         let module_name = module.name;
 
         query_modules.push(format!(
-            r#"pub mod {module_name} {{
-{query_imports}
-
-{queries_string}
-}}"#
+            "pub mod {module_name} {{ {query_imports}\n{queries_string} }}"
         ));
     }
+    let query_modules_string = format!("pub mod queries {{ {} }}", query_modules.join("\n\n"));
+    let top_level_comment = "// This file was generated with `cornucopia`. Do not modify.";
 
-    let generated_modules = format!(
-        "{type_modules} \n pub mod queries {{ {} }}",
-        query_modules.join("\n\n"),
-    );
+    let generated_modules =
+        format!("{top_level_comment}\n\n{type_modules}\n\n{query_modules_string}",);
 
-    std::fs::write(destination, generated_modules)?;
+    std::fs::write(destination, generated_modules)
+        .map_err(|err| Error::new(err.into(), destination))?;
 
     Ok(())
 }
@@ -329,10 +311,27 @@ pub(crate) mod error {
     use crate::pg_type::error::UnsupportedPostgresTypeError;
 
     #[derive(Debug, ThisError)]
-    #[error("Encountered an error while generating Rust code")]
-    pub(crate) enum Error {
+    #[error("{0}")]
+    pub(crate) enum ErrorVariants {
         UnsupportedPostgresTypeError(#[from] UnsupportedPostgresTypeError),
-        #[error("error while attempting to write generated modules")]
         Io(#[from] std::io::Error),
     }
+
+    #[derive(Debug, ThisError)]
+    #[error("Error while trying to write to destination file \"{path}\": {err}.")]
+    pub(crate) struct Error {
+        pub(crate) err: ErrorVariants,
+        pub(crate) path: String,
+    }
+
+    impl Error {
+        pub(crate) fn new(err: ErrorVariants, path: &str) -> Self {
+            Self {
+                path: std::fs::canonicalize(path)
+                    .map(|p| p.to_str().unwrap().to_string())
+                    .unwrap_or_else(|_| String::from(path)),
+                err,
+            }
+        }
+    }
 }
